@@ -466,7 +466,7 @@ static int cli_html_normalise(int fd, m_area_t *m_area, const char *dirname, tag
 {
 	int fd_tmp, tag_length, tag_arg_length, binary;
 	int retval=FALSE, escape, value = 0, hex, tag_val_length=0, table_pos, in_script=FALSE;
-	FILE *stream_in;
+	FILE *stream_in = NULL;
 	html_state state=HTML_NORM, next_state=HTML_BAD_STATE;
 	char filename[1024], tag[HTML_STR_LENGTH+1], tag_arg[HTML_STR_LENGTH+1];
 	char tag_val[HTML_STR_LENGTH+1], *tmp_file;
@@ -648,7 +648,7 @@ static int cli_html_normalise(int fd, m_area_t *m_area, const char *dirname, tag
 			case HTML_NORM:
 				if (*ptr == '<') {
 #ifdef CL_EXPERIMENTAL
-					ptrend=ptr-1; /* for use by scanContents */
+					ptrend=ptr; /* for use by scanContents */
 #endif
 					html_output_c(file_buff_o1, file_buff_o2, '<');
 					if (in_script) {
@@ -1513,7 +1513,7 @@ static int cli_html_normalise(int fd, m_area_t *m_area, const char *dirname, tag
 #ifdef CL_EXPERIMENTAL
 		if(hrefs && hrefs->scanContents && in_ahref && href_contents_begin)
 			/* end of line, append contents now, resume on next line */
-			html_tag_contents_append(hrefs,in_ahref,href_contents_begin,ptr-1);
+			html_tag_contents_append(hrefs,in_ahref,href_contents_begin,ptr);
 		ptrend = NULL;
 #endif
 		free(line);
