@@ -50,7 +50,7 @@ unsigned short ac_depth = AC_DEFAULT_DEPTH;
 
 int cli_ac_addpatt(struct cli_matcher *root, struct cli_ac_patt *pattern)
 {
-	struct cli_ac_node *pos, *next;
+	struct cli_ac_node *pos, *next, **newtable;
 	int i;
 
     if(pattern->length < ac_depth)
@@ -69,12 +69,15 @@ int cli_ac_addpatt(struct cli_matcher *root, struct cli_ac_patt *pattern)
 	    }
 
 	    root->ac_nodes++;
-	    root->ac_nodetable = (struct cli_ac_node **) cli_realloc(root->ac_nodetable, (root->ac_nodes) * sizeof(struct cli_ac_node *));
-	    if(root->ac_nodetable == NULL) {
-		cli_errmsg("cli_ac_addpatt(): Unable to realloc nodetable (%u bytes)\n", (root->ac_nodes) * sizeof(struct cli_matcher *));
+	    newtable = (struct cli_ac_node **) cli_realloc(root->ac_nodetable, (root->ac_nodes) * sizeof(struct cli_ac_node *));
+	    if(!newtable) {
+		root->ac_nodes--;
+		cli_errmsg("cli_ac_addpatt(): Unable to realloc root->ac_nodetable (%u bytes)\n", (root->ac_nodes) * sizeof(struct cli_matcher *));
+		free(next);
 		return CL_EMEM;
 	    }
-	    root->ac_nodetable[root->ac_nodes - 1] = next;
+	    newtable[root->ac_nodes - 1] = next;
+	    root->ac_nodetable = newtable;
 
 	    pos->trans[((unsigned char) pattern->pattern[i]) & 0xff] = next;
 	}
@@ -301,7 +304,7 @@ inline static int cli_findpos(const unsigned char *buffer, unsigned int depth, u
 
 int cli_ac_initdata(struct cli_ac_data *data, unsigned int partsigs, unsigned int tracklen)
 {
-	unsigned int i, j;
+	unsigned int i;
 
 
     if(!data) {
@@ -366,30 +369,26 @@ int cli_ac_initdata(struct cli_ac_data *data, unsigned int partsigs, unsigned in
      * allocation in cli_ac_scanbuff()
      */
 
-    for(i = 0; i < partsigs; i++) {
-	data->partoff[i] = (unsigned int *) cli_calloc(tracklen, sizeof(unsigned int));
+    data->partoff[0] = (unsigned int *) cli_calloc(partsigs * tracklen, sizeof(unsigned int));
 
-	if(!data->partoff[i]) {
-	    for(j = 0; j < i; j++)
-		free(data->partoff[j]);
-
-	    free(data->partoff);
-	    free(data->partcnt);
-	    free(data->offcnt);
-	    free(data->offidx);
-	    free(data->maxshift);
-	    cli_errmsg("cli_ac_init(): unable to cli_calloc(%u, %u)\n", tracklen, sizeof(unsigned int));
-	    return CL_EMEM;
-	}
+    if(!data->partoff[0]) {
+	free(data->partoff);
+	free(data->partcnt);
+	free(data->offcnt);
+	free(data->offidx);
+	free(data->maxshift);
+	cli_errmsg("cli_ac_init(): unable to cli_calloc(%u, %u)\n", partsigs * tracklen, sizeof(unsigned int));
+	return CL_EMEM;
     }
 
+    for(i = 0; i < partsigs; i++)
+	data->partoff[i] = data->partoff[0] + tracklen * i;
+
     return CL_SUCCESS;
 }
 
 void cli_ac_freedata(struct cli_ac_data *data)
 {
-	unsigned int i;
-
 
     if(data && data->partsigs) {
 	free(data->partcnt);
@@ -397,9 +396,7 @@ void cli_ac_freedata(struct cli_ac_data *data)
 	free(data->offidx);
 	free(data->maxshift);
 
-	for(i = 0; i < data->partsigs; i++)
-	    free(data->partoff[i]);
-
+	free(data->partoff[0]);
 	free(data->partoff);
     }
 }
