@@ -81,7 +81,7 @@ static pthread_mutex_t cli_gentempname_mutex = PTHREAD_MUTEX_INITIALIZER;
 #define       P_tmpdir        "C:\\WINDOWS\\TEMP"
 #endif
 
-#define CL_FLEVEL 15 /* don't touch it */
+#define CL_FLEVEL 16 /* don't touch it */
 
 short cli_debug_flag = 0, cli_leavetemps_flag = 0;
 
@@ -531,16 +531,22 @@ char *cli_gentempdesc(const char *dir, int *fd)
 char *cli_gentempstream(const char *dir, FILE **fs)
 {
 	char *name;
+	mode_t omask;
+
 
     name = cli_gentempname(dir);
+    if(!name)
+	return NULL;
 
-    if(name && ((*fs = fopen(name, "wb+")) == NULL)) {
+    omask = umask(077);
+    if((*fs = fopen(name, "wb+")) == NULL) {
 	cli_dbgmsg("cli_gentempstream(): can't create temp file: %s\n", name);
         free(name);
         name = NULL;
     }
+    umask(omask);
 
-    return(name);
+    return name;
 }
 
 #ifdef	C_WINDOWS
@@ -594,7 +600,7 @@ cli_rmdirs(const char *name)
 	if(strcmp(dent->d_name, "..") == 0)
 	    continue;
 
-	fname = cli_malloc(strlen(name) + strlen(dent->d_name) + 2, sizeof(char));
+	fname = cli_malloc(strlen(name) + strlen(dent->d_name) + 2);
 	if(fname == NULL) {
 	    closedir(dd);
 	    return -1;
@@ -928,9 +934,15 @@ cli_sanitise_filename(char *name)
 #ifdef  C_DARWIN
 		*name &= '\177';
 #endif
-		/* Also check for tab - "Heinz Martin" <Martin@hemag.ch> */
-#if     defined(MSDOS) || defined(C_CYGWIN) || defined(C_WINDOWS) || defined(C_OS2)
+               /* Also check for tab - "Heinz Martin" <Martin@hemag.ch> */
+#if    defined(MSDOS) || defined(C_OS2)
+               /*
+                * Don't take it from this that ClamAV supports DOS, it doesn't
+                * I don't know if spaces are legal in OS/2.
+                */
 		if(strchr("%/*?<>|\\\"+=,;:\t ~", *name))
+#elif  defined(C_CYGWIN) || defined(C_WINDOWS)
+		if(strchr("%/*?<>|\\\"+=,;:\t~", *name))
 #else
 		if(*name == '/')
 #endif
