@@ -78,7 +78,7 @@ cli_pdf(const char *dir, int desc, const cli_ctx *ctx)
 	const char *xrefstart;	/* cross reference table */
 	/*size_t xreflength;*/
 	int rc = CL_CLEAN;
-	struct table *md5table;
+	table_t *md5table;
 	int printed_predictor_message;
 	int printed_embedded_font_message;
 	struct stat statb;
@@ -88,7 +88,7 @@ cli_pdf(const char *dir, int desc, const cli_ctx *ctx)
 	if(fstat(desc, &statb) < 0)
 		return CL_EOPEN;
 
-	size = (size_t)statb.st_size;
+	size = statb.st_size;
 
 	if(size == 0)
 		return CL_CLEAN;
@@ -216,7 +216,7 @@ cli_pdf(const char *dir, int desc, const cli_ctx *ctx)
 		/*int object_number, generation_number;*/
 		const char *objstart, *objend, *streamstart, *streamend;
 		char *md5digest;
-		size_t length, objlen, real_streamlen, calculated_streamlen;
+		unsigned long length, objlen, real_streamlen, calculated_streamlen;
 		int is_embedded_font, predictor;
 		char fullname[NAME_MAX + 1];
 
@@ -262,7 +262,7 @@ cli_pdf(const char *dir, int desc, const cli_ctx *ctx)
 		}
 		bytesleft -= (objend - p) + 6;
 		p = &objend[6];
-		objlen = (size_t)(objend - objstart);
+		objlen = (unsigned long)(objend - objstart);
 
 		/* Is this object a stream? */
 		streamstart = cli_pmemstr(objstart, objlen, "stream", 6);
@@ -291,16 +291,21 @@ cli_pdf(const char *dir, int desc, const cli_ctx *ctx)
 					 */
 					if((bytesleft > 11) && strncmp(q, " 0 R", 4) == 0) {
 						const char *r;
-						char b[13];
+						char b[14];
 
 						q += 4;
-						cli_dbgmsg("Length is in indirect obj %d\n",
+						cli_dbgmsg("Length is in indirect obj %ld\n",
 							length);
 						snprintf(b, sizeof(b),
-							"%d 0 obj", length);
-						length = strlen(b);
+							"\n%ld 0 obj", length);
+						length = (unsigned long)strlen(b);
 						r = cli_pmemstr(alloced ? alloced : buf,
 							size, b, length);
+						if(r == NULL) {
+							b[0] = '\r';
+							r = cli_pmemstr(alloced ? alloced : buf,
+								size, b, length);
+						}
 						if(r) {
 							r += length - 1;
 							r = pdf_nextobject(r, bytesleft - (r - q));
@@ -308,12 +313,13 @@ cli_pdf(const char *dir, int desc, const cli_ctx *ctx)
 								length = atoi(r);
 								while(isdigit(*r))
 									r++;
-								cli_dbgmsg("length in '%s' %d\n",
-									b, length);
+								cli_dbgmsg("length in '%s' %ld\n",
+									&b[1],
+									length);
 							}
 						} else
 							cli_warnmsg("Couldn't find '%s'\n",
-								b);
+								&b[1]);
 					}
 					q--;
 				} else if(strncmp(q, "Length2 ", 8) == 0)
@@ -428,7 +434,7 @@ cli_pdf(const char *dir, int desc, const cli_ctx *ctx)
 		if(calculated_streamlen != real_streamlen)
 			cli_dbgmsg("cli_pdf: Incorrect Length field in file attempting to recover\n");
 
-		cli_dbgmsg("length %d, calculated_streamlen %d isFlate %d isASCII85 %d\n",
+		cli_dbgmsg("length %ld, calculated_streamlen %ld isFlate %d isASCII85 %d\n",
 			length, calculated_streamlen,
 			is_flatedecode, is_ascii85decode);
 
@@ -460,10 +466,20 @@ cli_pdf(const char *dir, int desc, const cli_ctx *ctx)
 				continue;
 			}
 			if(ret) {
-				real_streamlen = (size_t)ret;
+				char *t;
+
+				real_streamlen = ret;
 				/* free unused trailing bytes */
-				tmpbuf = cli_realloc(tmpbuf,
+				t = cli_realloc(tmpbuf,
 					calculated_streamlen);
+				if(t == NULL) {
+					free(tmpbuf);
+					close(fout);
+					unlink(fullname);
+					rc = CL_EMEM;
+					continue;
+				}
+				tmpbuf = t;
 				/*
 				 * Note that it will probably be both
 				 * ascii85encoded and flateencoded
@@ -551,6 +567,11 @@ flatedecode(unsigned char *buf, off_t len, int fout, const cli_ctx *ctx)
 
 	cli_dbgmsg("cli_pdf: flatedecode %lu bytes\n", (unsigned long)len);
 
+	if(len == 0) {
+		cli_warnmsg("cli_pdf: flatedecode len == 0\n");
+		return Z_OK;
+	}
+
 #ifdef	SAVE_TMP
 	/*
 	 * Copy the embedded area for debugging, so that if it falls over
