@@ -13,14 +13,18 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA 02110-1301, USA.
  */
 
 #ifndef __SCANNERS_H
 #define __SCANNERS_H
 
 #include "clamav.h"
+#include "others.h"
 
-int cli_magic_scandesc(int desc, const char **virname, unsigned long int *scanned, const struct cl_node *root, const struct cl_limits *limits, unsigned int options, unsigned int arec, unsigned int mrec);
+int cli_magic_scandesc(int desc, cli_ctx *ctx);
+
+int cli_scandir(const char *dirname, cli_ctx *ctx);
 
 #endif
