@@ -942,8 +942,8 @@ static int add_vm_code(unpack_data_t *unpack_data, unsigned int first_byte,
 	}
 	if (new_filter) {
 		vm_codesize = rarvm_read_data(&rarvm_input);
-		if (vm_codesize >= 0x1000 || vm_codesize == 0) {
-			cli_dbgmsg("ERROR: vm_codesize=0x%x\n", vm_codesize);
+		if (vm_codesize >= 0x1000 || vm_codesize == 0 || (vm_codesize > rarvm_input.buf_size)) {
+			cli_dbgmsg("ERROR: vm_codesize=0x%x buf_size=0x%x\n", vm_codesize, rarvm_input.buf_size);
 			return FALSE;
 		}
 		vm_code = (unsigned char *) cli_malloc(vm_codesize);
@@ -1015,6 +1015,10 @@ static int add_vm_code(unpack_data_t *unpack_data, unsigned int first_byte,
 		}
 		global_data = &stack_filter->prg.global_data[VM_FIXEDGLOBALSIZE];
 		for (i=0 ; i< data_size ; i++) {
+			if ((rarvm_input.in_addr+2) > rarvm_input.buf_size) {
+				cli_dbgmsg("Buffer truncated\n");
+				return FALSE;
+			}
 			global_data[i] = rarvm_getbits(&rarvm_input) >> 8;
 			rar_dbgmsg("global_data[%d] = %d\n", i, global_data[i]);
 			rarvm_addbits(&rarvm_input, 8);
@@ -1635,15 +1639,12 @@ int cli_unrar_extract_next(rar_state_t* state,const char* dirname)
 						((state->main_hdr->flags&MHD_SOLID)!=0), state->unpack_data);
 			} else {
 				if ((state->file_count == 1) && (state->file_header->flags & LHD_SOLID)) {
-					cli_warnmsg("RAR: First file can't be SOLID.\n");
-					
-					free(state->file_header->filename);
-					free(state->file_header);
-					return CL_ERAR;
-				} else {
-					retval = rar_unpack(state->fd, state->file_header->unpack_ver,
-							state->file_header->flags & LHD_SOLID,	state->unpack_data);
+					cli_warnmsg("RAR: Bad header. First file can't be SOLID.\n");
+					cli_warnmsg("RAR: Clearing flag and continuing.\n");
+					state->file_header->flags -= LHD_SOLID;
 				}
+				retval = rar_unpack(state->fd, state->file_header->unpack_ver,
+							state->file_header->flags & LHD_SOLID,	state->unpack_data);
 			}
 			cli_dbgmsg("Expected File CRC: 0x%x\n", state->file_header->file_crc);
 			cli_dbgmsg("Computed File CRC: 0x%x\n", state->unpack_data->unp_crc^0xffffffff);
